<?php

namespace kwy\sunmi;

class SunmiStore {
	
	/**
	 * @var SunmiApi
	 */
	private $sunmiApi;

    /**
     * SunmiStore constructor.
     * @param SunmiApi $api
     */
	public function __construct(SunmiApi $api){
		$this->sunmiApi=$api;
	}
	
	
	/**
     * 获取商场门店列表
     * @throws \Exception 接口异常
     * @return array
	 * 'store_list' array
	 */
	public function getMerStoreList(){
	    $function='/software/getMerStoreList';
	    $biz_params=[
	        'merchant_code'=>'MALL0001',
	    ];
	    return $this->sunmiApi->request($function, $biz_params);
	}
	
	/**
	 * 上传会员数据
	 * @param array $params 参数*必填<br>
	 * store_code string *门店编号<br>
	 * member_id string *会员ID<br>
	 * member_type int *交易类型 1：储值卡 2：非储值卡 <br>
	 * member_total float  *会员卡充值总额<br>
	 * member_cost float *消费总额 <br>
	 * member_balance int * 余额<br>
	 * ext_data jsonString  扩展字段 备用 非必填<br>
     * @throws \Exception 接口异常
	 * @return mixed
	 */
	public function postMember($params){
		$function='/software/postMember';
		$biz_params=array_merge([],$params);
		return $this->sunmiApi->request($function, $biz_params);
	}
	
	/**
	 * 上传门店信息
     * @param array $params  参数*必填<br>
	 * store_code  * <br>
	 * store_name  * <br>
	 * mobile 联系手机号  *<br>
	 * contactor 门店联系人姓名  *<br>
	 * address 门店地址  *<br>
	 * status  状态 * 0停用  1启用<br>
     * @throws \Exception 接口异常
	 * @return mixed
	 */
	public function postStore($params){
		$function='/software/postStore';
		$biz_params=array_merge([],$params);
		return $this->sunmiApi->request($function, $biz_params);
	}
	
	/**
	 * 上传交易数据
     * @param array $params 参数*必填<br>
	 * store_code string *门店编号<br>
	 * trade_no string *交易单号<br>
	 * trade_type int *交易类型 1：销货 2：退货 <br>
	 * trade_time int  *交易时间 UNIX时间<br>
	 * trade_total float *保留两位小数 交易金额总订单金额 包含优惠 <br>
	 * pay_type int * 支付方式 1:现金 2:支付宝  3:微信 4:QQ钱包 5:京东钱包 6:银行卡刷卡 7:银联二维码 8:其他 组合支付方式计为其他<br>
	 * people_num int * 默认1 购买人数<br>
	 * ext_data jsonString  扩展字段 备用 非必填<br>
	 * order_goodlist jsonString 非必填 交易商品列表 例：[{“good_spec”:”xx”,” good_name”:”xx”,” good_num”:8},{“good_spec”:”x2”,” good_name”:”y2”,” good_num”:2}]<br>
	 * @throws \Exception 接口异常
	 * @return mixed
	 */
	public function postTrade($params){
		$function='/software/postTrade';
		$biz_params=array_merge([
				'software_name'=>'客无忧收银系统',#交易时sass软件名称
				'software_spec'=>'客无忧收银系统',#软件规格
		],$params);
		return $this->sunmiApi->request($function, $biz_params);
		
	}
	
	/**
	 * 获取商米支付类型
	 * @param string $pay_method
	 * @return number
	 */
	public function getSummiPayType($pay_method){
	    if ($pay_method=='微信支付'){
	        return 3;
	    }elseif ($pay_method=='现金支付') {
	        return 1;
	    }elseif ($pay_method=='支付宝支付'){
	        return 2;
	    }elseif ($pay_method=='银行卡支付'){
	        return 6;
	    }else {
	        return 8;
	    }
	}
	
}
