<?php
/**
 *
 * Auther: heyu
 * DateTime: 2019-08-28 11:07
 *
 */

namespace kwy\sunmi\product;


use kwy\sunmi\MD5Sign;
use kwy\sunmi\Util;

class ProductApi
{

    use MD5Sign;

    private $log='';

    /**
     * 批量创建导入商品数据 多个商品对象数据
     * @api /product/create
     * @param int $shop_id 客无忧店铺id
     * @param Product[] $productList
     * @throws \Exception
     */
    public function create($shop_id,$productList){
        $api='/product/create';
        $list=[];
        foreach ($productList as $v){
            $list[]=$v->toArray();
        }
        $ret=$this->request($api,['shop_id'=>$shop_id,'product_list'=>json_encode($list)]);
    }

    /**
     * 批量更新商品信息
     * @api /product/update
     * @param int $shop_id 客无忧店铺id
     * @param Product[] $productList
     * @throws \Exception
     */
    public function update($shop_id,$productList){
        $api='/product/update';
        $list=[];
        foreach ($productList as $v){
            $list[]=$v->toArray();
        }
        $ret=$this->request($api,['shop_id'=>$shop_id,'product_list'=>json_encode($list)]);
    }

    /**
     * @param int $shop_id
     * @param array $productIdArray
     * @throws \Exception
     */
    public function delete($shop_id,$productIdArray){
        $api='/product/delete';
        $ret=$this->request($api,['shop_id'=>$shop_id,'product_key_list'=>json_encode($productIdArray)]);
    }

    public function getLog(){
        return $this->log;
    }


    /**
     * @param string $api
     * @param array $data
     * @return mixed
     * @throws \Exception
     */
    private function request($api,$data){
        $url=Config::getHost().$api;

        $data=array_merge($data,$this->getCommonParams());
        $data['sign']=$this->getSign($data,Config::$secret_key);

        $data=http_build_query($data);
        $ch=curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);//url
        curl_setopt($ch, CURLOPT_POST, 1);//post
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);//返回结果curl
        curl_setopt($ch, CURLOPT_IPRESOLVE, CURL_IPRESOLVE_V4 );//强制ipv4解析
        curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER,0);      //忽略校验证书
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, Config::$timeout);

        #代理访问
        //curl_setopt($ch, CURLOPT_PROXY, "127.0.0.1"); //代理服务器地址
        //curl_setopt($ch, CURLOPT_PROXYPORT,'8888'); //代理服务器端口
        //curl_setopt($ch, CURLINFO_HEADER_OUT, true); //TRUE 时追踪句柄的请求字符串，从 PHP 5.1.3 开始可用。这个很关键，就是允许你查看请求header
        $this->log=date('Y-m-d H:i:s').' API_URL:'.$url."\n API_PARAMS: ".(is_string($data)?$data:json_encode($data))."\n";

        $ret = curl_exec($ch);
        if ($ret===false){
            $err_code=curl_errno($ch);
            $err_msg=curl_error($ch);
            curl_close($ch);
            $this->log.='CURL ERROR:('.$err_code.')'.$err_msg."\n";
            throw new \Exception($err_msg);
        }
        curl_close($ch);
        $this->log.="API_RETURN: ".$ret."\n";
        $arr_ret=json_decode($ret,true);
        if (empty($arr_ret)){
            throw new \Exception('远端返回内容不合法');
        }
        if ($arr_ret['code']!==0){
            throw new \Exception($arr_ret['msg']);
        }
        return $arr_ret;
    }

    /**
     * @param $params
     * @return array
     */
    private function getCommonParams(){
        return [
            'app_id'=>Config::$app_id,
            'timestamp'=>time(),
            'random'=>Util::getNonceStr(10),
        ];
    }
}